@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 3.0.5.  */
+/* A Bison parser, made by GNU Bison 3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
@@ -40,11 +40,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.5"
+#define YYBISON_VERSION "3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -61,8 +64,8 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "getdate.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 1 "getdate.y" /* yacc.c:338  */
 
 /*
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
@@ -233,13 +236,16 @@ static int	yyRelSeconds;
 static int	yyRelYear;
 
 
-#line 237 "getdate.c" /* yacc.c:339  */
-
+#line 240 "getdate.c" /* yacc.c:338  */
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -306,12 +312,12 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 172 "getdate.y" /* yacc.c:355  */
+#line 172 "getdate.y" /* yacc.c:353  */
 
     int			Number;
     enum _MERIDIAN	Meridian;
 
-#line 315 "getdate.c" /* yacc.c:355  */
+#line 321 "getdate.c" /* yacc.c:353  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -326,9 +332,7 @@ int yyparse (void);
 
 
 
-/* Copy the second part of user declarations.  */
 
-#line 332 "getdate.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -349,13 +353,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -367,7 +371,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -403,15 +407,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -419,7 +414,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -587,7 +582,7 @@ union yyalloc
 #define YYMAXUTOK   273
 
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
    as returned by yylex, without out-of-bounds checking.  */
@@ -837,37 +832,37 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -901,7 +896,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -1034,7 +1029,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1276,12 +1271,12 @@ yyparse (void)
   yyssp++;
 
  yysetstate:
-  *yyssp = yystate;
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
 #ifdef yyoverflow
       {
@@ -1299,7 +1294,6 @@ yyparse (void)
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
@@ -1333,7 +1327,7 @@ yyparse (void)
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
@@ -1444,69 +1438,69 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 192 "getdate.y" /* yacc.c:1648  */
+#line 192 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHaveTime++;
 	}
-#line 1452 "getdate.c" /* yacc.c:1648  */
+#line 1446 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 5:
-#line 195 "getdate.y" /* yacc.c:1648  */
+#line 195 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHaveZone++;
 	}
-#line 1460 "getdate.c" /* yacc.c:1648  */
+#line 1454 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 6:
-#line 198 "getdate.y" /* yacc.c:1648  */
+#line 198 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHaveDate++;
 	}
-#line 1468 "getdate.c" /* yacc.c:1648  */
+#line 1462 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 7:
-#line 201 "getdate.y" /* yacc.c:1648  */
+#line 201 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHaveDay++;
 	}
-#line 1476 "getdate.c" /* yacc.c:1648  */
+#line 1470 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 8:
-#line 204 "getdate.y" /* yacc.c:1648  */
+#line 204 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHaveRel++;
 	}
-#line 1484 "getdate.c" /* yacc.c:1648  */
+#line 1478 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 10:
-#line 210 "getdate.y" /* yacc.c:1648  */
+#line 210 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHour = (yyvsp[-1].Number);
 	    yyMinutes = 0;
 	    yySeconds = 0;
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1495 "getdate.c" /* yacc.c:1648  */
+#line 1489 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 11:
-#line 216 "getdate.y" /* yacc.c:1648  */
+#line 216 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
 	    yySeconds = 0;
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1506 "getdate.c" /* yacc.c:1648  */
+#line 1500 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 12:
-#line 222 "getdate.y" /* yacc.c:1648  */
+#line 222 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
@@ -1516,22 +1510,22 @@ yyreduce:
 			  ? -(yyvsp[0].Number) % 100 + (-(yyvsp[0].Number) / 100) * 60
 			  : - ((yyvsp[0].Number) % 100 + ((yyvsp[0].Number) / 100) * 60));
 	}
-#line 1520 "getdate.c" /* yacc.c:1648  */
+#line 1514 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 13:
-#line 231 "getdate.y" /* yacc.c:1648  */
+#line 231 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
 	    yySeconds = (yyvsp[-1].Number);
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1531 "getdate.c" /* yacc.c:1648  */
+#line 1525 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 14:
-#line 237 "getdate.y" /* yacc.c:1648  */
+#line 237 "getdate.y" /* yacc.c:1645  */
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
@@ -1542,71 +1536,71 @@ yyreduce:
 			  ? -(yyvsp[0].Number) % 100 + (-(yyvsp[0].Number) / 100) * 60
 			  : - ((yyvsp[0].Number) % 100 + ((yyvsp[0].Number) / 100) * 60));
 	}
-#line 1546 "getdate.c" /* yacc.c:1648  */
+#line 1540 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 15:
-#line 249 "getdate.y" /* yacc.c:1648  */
+#line 249 "getdate.y" /* yacc.c:1645  */
     {
 	    yyTimezone = (yyvsp[0].Number);
 	}
-#line 1554 "getdate.c" /* yacc.c:1648  */
+#line 1548 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 16:
-#line 252 "getdate.y" /* yacc.c:1648  */
+#line 252 "getdate.y" /* yacc.c:1645  */
     {
 	    yyTimezone = (yyvsp[0].Number) - 60;
 	}
-#line 1562 "getdate.c" /* yacc.c:1648  */
+#line 1556 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 17:
-#line 256 "getdate.y" /* yacc.c:1648  */
+#line 256 "getdate.y" /* yacc.c:1645  */
     {
 	    yyTimezone = (yyvsp[-1].Number) - 60;
 	}
-#line 1570 "getdate.c" /* yacc.c:1648  */
+#line 1564 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 18:
-#line 261 "getdate.y" /* yacc.c:1648  */
+#line 261 "getdate.y" /* yacc.c:1645  */
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[0].Number);
 	}
-#line 1579 "getdate.c" /* yacc.c:1648  */
+#line 1573 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 19:
-#line 265 "getdate.y" /* yacc.c:1648  */
+#line 265 "getdate.y" /* yacc.c:1645  */
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[-1].Number);
 	}
-#line 1588 "getdate.c" /* yacc.c:1648  */
+#line 1582 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 20:
-#line 269 "getdate.y" /* yacc.c:1648  */
+#line 269 "getdate.y" /* yacc.c:1645  */
     {
 	    yyDayOrdinal = (yyvsp[-1].Number);
 	    yyDayNumber = (yyvsp[0].Number);
 	}
-#line 1597 "getdate.c" /* yacc.c:1648  */
+#line 1591 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 21:
-#line 275 "getdate.y" /* yacc.c:1648  */
+#line 275 "getdate.y" /* yacc.c:1645  */
     {
 	    yyMonth = (yyvsp[-2].Number);
 	    yyDay = (yyvsp[0].Number);
 	}
-#line 1606 "getdate.c" /* yacc.c:1648  */
+#line 1600 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 22:
-#line 279 "getdate.y" /* yacc.c:1648  */
+#line 279 "getdate.y" /* yacc.c:1645  */
     {
 	  /* Interpret as YYYY/MM/DD if $1 >= 1000, otherwise as MM/DD/YY.
 	     The goal in recognizing YYYY/MM/DD is solely to support legacy
@@ -1625,71 +1619,71 @@ yyreduce:
 	      yyYear = (yyvsp[0].Number);
 	    }
 	}
-#line 1629 "getdate.c" /* yacc.c:1648  */
+#line 1623 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 23:
-#line 297 "getdate.y" /* yacc.c:1648  */
+#line 297 "getdate.y" /* yacc.c:1645  */
     {
 	    /* ISO 8601 format.  yyyy-mm-dd.  */
 	    yyYear = (yyvsp[-2].Number);
 	    yyMonth = -(yyvsp[-1].Number);
 	    yyDay = -(yyvsp[0].Number);
 	}
-#line 1640 "getdate.c" /* yacc.c:1648  */
+#line 1634 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 24:
-#line 303 "getdate.y" /* yacc.c:1648  */
+#line 303 "getdate.y" /* yacc.c:1645  */
     {
 	    /* e.g. 17-JUN-1992.  */
 	    yyDay = (yyvsp[-2].Number);
 	    yyMonth = (yyvsp[-1].Number);
 	    yyYear = -(yyvsp[0].Number);
 	}
-#line 1651 "getdate.c" /* yacc.c:1648  */
+#line 1645 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 25:
-#line 309 "getdate.y" /* yacc.c:1648  */
+#line 309 "getdate.y" /* yacc.c:1645  */
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[0].Number);
 	}
-#line 1660 "getdate.c" /* yacc.c:1648  */
+#line 1654 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 26:
-#line 313 "getdate.y" /* yacc.c:1648  */
+#line 313 "getdate.y" /* yacc.c:1645  */
     {
 	    yyMonth = (yyvsp[-3].Number);
 	    yyDay = (yyvsp[-2].Number);
 	    yyYear = (yyvsp[0].Number);
 	}
-#line 1670 "getdate.c" /* yacc.c:1648  */
+#line 1664 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 27:
-#line 318 "getdate.y" /* yacc.c:1648  */
+#line 318 "getdate.y" /* yacc.c:1645  */
     {
 	    yyMonth = (yyvsp[0].Number);
 	    yyDay = (yyvsp[-1].Number);
 	}
-#line 1679 "getdate.c" /* yacc.c:1648  */
+#line 1673 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 28:
-#line 322 "getdate.y" /* yacc.c:1648  */
+#line 322 "getdate.y" /* yacc.c:1645  */
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[-2].Number);
 	    yyYear = (yyvsp[0].Number);
 	}
-#line 1689 "getdate.c" /* yacc.c:1648  */
+#line 1683 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 29:
-#line 329 "getdate.y" /* yacc.c:1648  */
+#line 329 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelSeconds = -yyRelSeconds;
 	    yyRelMinutes = -yyRelMinutes;
@@ -1698,155 +1692,155 @@ yyreduce:
 	    yyRelMonth = -yyRelMonth;
 	    yyRelYear = -yyRelYear;
 	}
-#line 1702 "getdate.c" /* yacc.c:1648  */
+#line 1696 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 31:
-#line 340 "getdate.y" /* yacc.c:1648  */
+#line 340 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelYear += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1710 "getdate.c" /* yacc.c:1648  */
+#line 1704 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 32:
-#line 343 "getdate.y" /* yacc.c:1648  */
+#line 343 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelYear += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1718 "getdate.c" /* yacc.c:1648  */
+#line 1712 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 33:
-#line 346 "getdate.y" /* yacc.c:1648  */
+#line 346 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelYear++;
 	}
-#line 1726 "getdate.c" /* yacc.c:1648  */
+#line 1720 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 34:
-#line 349 "getdate.y" /* yacc.c:1648  */
+#line 349 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1734 "getdate.c" /* yacc.c:1648  */
+#line 1728 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 35:
-#line 352 "getdate.y" /* yacc.c:1648  */
+#line 352 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1742 "getdate.c" /* yacc.c:1648  */
+#line 1736 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 36:
-#line 355 "getdate.y" /* yacc.c:1648  */
+#line 355 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelMonth++;
 	}
-#line 1750 "getdate.c" /* yacc.c:1648  */
+#line 1744 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 37:
-#line 358 "getdate.y" /* yacc.c:1648  */
+#line 358 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelDay += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1758 "getdate.c" /* yacc.c:1648  */
+#line 1752 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 38:
-#line 361 "getdate.y" /* yacc.c:1648  */
+#line 361 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelDay += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1766 "getdate.c" /* yacc.c:1648  */
+#line 1760 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 39:
-#line 364 "getdate.y" /* yacc.c:1648  */
+#line 364 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelDay++;
 	}
-#line 1774 "getdate.c" /* yacc.c:1648  */
+#line 1768 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 40:
-#line 367 "getdate.y" /* yacc.c:1648  */
+#line 367 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelHour += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1782 "getdate.c" /* yacc.c:1648  */
+#line 1776 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 41:
-#line 370 "getdate.y" /* yacc.c:1648  */
+#line 370 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelHour += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1790 "getdate.c" /* yacc.c:1648  */
+#line 1784 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 42:
-#line 373 "getdate.y" /* yacc.c:1648  */
+#line 373 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelHour++;
 	}
-#line 1798 "getdate.c" /* yacc.c:1648  */
+#line 1792 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 43:
-#line 376 "getdate.y" /* yacc.c:1648  */
+#line 376 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelMinutes += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1806 "getdate.c" /* yacc.c:1648  */
+#line 1800 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 44:
-#line 379 "getdate.y" /* yacc.c:1648  */
+#line 379 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelMinutes += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1814 "getdate.c" /* yacc.c:1648  */
+#line 1808 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 45:
-#line 382 "getdate.y" /* yacc.c:1648  */
+#line 382 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelMinutes++;
 	}
-#line 1822 "getdate.c" /* yacc.c:1648  */
+#line 1816 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 46:
-#line 385 "getdate.y" /* yacc.c:1648  */
+#line 385 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1830 "getdate.c" /* yacc.c:1648  */
+#line 1824 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 47:
-#line 388 "getdate.y" /* yacc.c:1648  */
+#line 388 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1838 "getdate.c" /* yacc.c:1648  */
+#line 1832 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 48:
-#line 391 "getdate.y" /* yacc.c:1648  */
+#line 391 "getdate.y" /* yacc.c:1645  */
     {
 	    yyRelSeconds++;
 	}
-#line 1846 "getdate.c" /* yacc.c:1648  */
+#line 1840 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 49:
-#line 397 "getdate.y" /* yacc.c:1648  */
+#line 397 "getdate.y" /* yacc.c:1645  */
     {
 	    if ((yyHaveTime != 0) && (yyHaveDate != 0) && (yyHaveRel == 0))
 	      yyYear = (yyvsp[0].Number);
@@ -1877,27 +1871,27 @@ yyreduce:
 		  }
 	      }
 	  }
-#line 1881 "getdate.c" /* yacc.c:1648  */
+#line 1875 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 50:
-#line 430 "getdate.y" /* yacc.c:1648  */
+#line 430 "getdate.y" /* yacc.c:1645  */
     {
 	    (yyval.Meridian) = MER24;
 	  }
-#line 1889 "getdate.c" /* yacc.c:1648  */
+#line 1883 "getdate.c" /* yacc.c:1645  */
     break;
 
   case 51:
-#line 434 "getdate.y" /* yacc.c:1648  */
+#line 434 "getdate.y" /* yacc.c:1645  */
     {
 	    (yyval.Meridian) = (yyvsp[0].Meridian);
 	  }
-#line 1897 "getdate.c" /* yacc.c:1648  */
+#line 1891 "getdate.c" /* yacc.c:1645  */
     break;
 
 
-#line 1901 "getdate.c" /* yacc.c:1648  */
+#line 1895 "getdate.c" /* yacc.c:1645  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1922,14 +1916,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -2125,7 +2118,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 439 "getdate.y" /* yacc.c:1907  */
+#line 439 "getdate.y" /* yacc.c:1903  */
 
 
 /* Month and day table. */
